<!-- markdownlint-disable -->



# <kbd>module</kbd> `tool.entrypoint`






---



## <kbd>class</kbd> `ToolEntrypoint`
Class that contains methods for the entrypoint for a tool. 




---



### <kbd>method</kbd> `launch`

```python
launch(tool: UnstractAbstractTool, args: list) → None
```

Entrypoint function for a tool. 

It parses the arguments passed to a tool and executes the intended command. 



**Args:**
 
 - <b>`tool`</b> (UnstractAbstractTool):  Tool to execute 
 - <b>`args`</b> (List[str]):  Arguments passed to a tool 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
